==> vtk-v4.0.2.zip: vtk-v4.0.2/Rendering/vtkMesaProperty.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkMesaProperty.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-2001 Ken Martin, Will Schroeder, Bill Lorensen 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither name of Ken Martin, Will Schroeder, or Bill Lorensen nor the names
   of any contributors may be used to endorse or promote products derived
   from this software without specific prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkMesaProperty - Mesa property
// .SECTION Description
// vtkMesaProperty is a concrete implementation of the abstract class 
// vtkProperty. vtkMesaProperty interfaces to the Mesa rendering library.

#ifndef __vtkMesaProperty_h
#define __vtkMesaProperty_h

#include "vtkProperty.h"

class vtkMesaRenderer;

class VTK_RENDERING_EXPORT vtkMesaProperty : public vtkProperty
{
public:
  static vtkMesaProperty *New();
  vtkTypeMacro(vtkMesaProperty,vtkProperty);

  // Description:
  // Implement base class method.
  void Render(vtkActor *a, vtkRenderer *ren);

  // Description:
  // Implement base class method.
  void BackfaceRender(vtkActor *a, vtkRenderer *ren);

protected:
  vtkMesaProperty() {};
  ~vtkMesaProperty() {};
private:
  vtkMesaProperty(const vtkMesaProperty&);  // Not implemented.
  void operator=(const vtkMesaProperty&);  // Not implemented.
};

#endif

==> vtk-v4.2.4.zip: vtk-v4.2.4/Rendering/vtkMesaProperty.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkMesaProperty.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

  Copyright (c) 1993-2002 Ken Martin, Will Schroeder, Bill Lorensen 
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkMesaProperty - Mesa property
// .SECTION Description
// vtkMesaProperty is a concrete implementation of the abstract class 
// vtkProperty. vtkMesaProperty interfaces to the Mesa rendering library.

#ifndef __vtkMesaProperty_h
#define __vtkMesaProperty_h

#include "vtkProperty.h"

class vtkMesaRenderer;

class VTK_RENDERING_EXPORT vtkMesaProperty : public vtkProperty
{
public:
  static vtkMesaProperty *New();
  vtkTypeRevisionMacro(vtkMesaProperty,vtkProperty);
  virtual void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Implement base class method.
  void Render(vtkActor *a, vtkRenderer *ren);

  // Description:
  // Implement base class method.
  void BackfaceRender(vtkActor *a, vtkRenderer *ren);

protected:
  vtkMesaProperty() {};
  ~vtkMesaProperty() {};
private:
  vtkMesaProperty(const vtkMesaProperty&);  // Not implemented.
  void operator=(const vtkMesaProperty&);  // Not implemented.
};

#endif
